@@ -18,6 +18,8 @@ DarwinVersionNumber = Tuple[int, int, int]
 PathLike = Union[str, Path]
 ErrorHandler = Callable[[int, str], None]
 
+ItemId = Union[str, int]
+
 
 @dataclass
 class Team:
@@ -103,6 +105,9 @@ class Annotation:
     #: List of ``SubAnnotations`` belonging to this ``Annotation``.
     subs: List[SubAnnotation] = field(default_factory=list)
 
+    #: V2 slots this annotation belogs to
+    slot_names: List[str] = field(default_factory=list)
+
     def get_sub(self, annotation_type: str) -> Optional[SubAnnotation]:
         """
         Returns the first SubAnnotation that matches the given type.
@@ -145,6 +150,9 @@ class VideoAnnotation:
     #: Whether this ``VideoAnnotation`` is interpolated or not.
     interpolated: bool
 
+    #: V2 slots this annotation belogs to
+    slot_names: List[str] = field(default_factory=list)
+
     def get_data(
         self, only_keyframes: bool = True, post_processing: Optional[Callable[[Annotation, Any], Any]] = None
     ) -> Dict[str, Any]:
@@ -257,7 +265,13 @@ class AnnotationFile:
 
 
 def make_bounding_box(
-    class_name: str, x: float, y: float, w: float, h: float, subs: Optional[List[SubAnnotation]] = None
+    class_name: str,
+    x: float,
+    y: float,
+    w: float,
+    h: float,
+    subs: Optional[List[SubAnnotation]] = None,
+    slot_names: Optional[List[str]] = None,
 ) -> Annotation:
     """
     Creates and returns a bounding box annotation. ``x``, ``y``, ``w`` and ``h`` are rounded to 3
@@ -287,10 +301,13 @@ def make_bounding_box(
         AnnotationClass(class_name, "bounding_box"),
         {"x": round(x, 3), "y": round(y, 3), "w": round(w, 3), "h": round(h, 3)},
         subs or [],
+        slot_names=slot_names or [],
     )
 
 
-def make_tag(class_name: str, subs: Optional[List[SubAnnotation]] = None) -> Annotation:
+def make_tag(
+    class_name: str, subs: Optional[List[SubAnnotation]] = None, slot_names: Optional[List[str]] = None
+) -> Annotation:
     """
     Creates and returns a tag annotation.
 
@@ -306,7 +323,7 @@ def make_tag(class_name: str, subs: Optional[List[SubAnnotation]] = None) -> Ann
     Annotation
         A tag ``Annotation``.
     """
-    return Annotation(AnnotationClass(class_name, "tag"), {}, subs or [])
+    return Annotation(AnnotationClass(class_name, "tag"), {}, subs or [], slot_names=slot_names)
 
 
 def make_polygon(
@@ -314,6 +331,7 @@ def make_polygon(
     point_path: List[Point],
     bounding_box: Optional[Dict] = None,
     subs: Optional[List[SubAnnotation]] = None,
+    slot_names: Optional[List[str]] = None,
 ) -> Annotation:
     """
     Creates and returns a polygon annotation.
@@ -346,6 +364,7 @@ def make_polygon(
         AnnotationClass(class_name, "polygon"),
         _maybe_add_bounding_box_data({"path": point_path}, bounding_box),
         subs or [],
+        slot_names=slot_names or [],
     )
 
 
@@ -354,6 +373,7 @@ def make_complex_polygon(
     point_paths: List[List[Point]],
     bounding_box: Optional[Dict] = None,
     subs: Optional[List[SubAnnotation]] = None,
+    slot_names: Optional[List[str]] = None,
 ) -> Annotation:
     """
     Creates and returns a complex polygon annotation. Complex polygons are those who have holes
@@ -396,10 +416,17 @@ def make_complex_polygon(
         AnnotationClass(class_name, "complex_polygon", "polygon"),
         _maybe_add_bounding_box_data({"paths": point_paths}, bounding_box),
         subs or [],
+        slot_names=slot_names or [],
     )
 
 
-def make_keypoint(class_name: str, x: float, y: float, subs: Optional[List[SubAnnotation]] = None) -> Annotation:
+def make_keypoint(
+    class_name: str,
+    x: float,
+    y: float,
+    subs: Optional[List[SubAnnotation]] = None,
+    slot_names: Optional[List[str]] = None,
+) -> Annotation:
     """
     Creates and returns a keypoint, aka point, annotation.
 
@@ -419,10 +446,15 @@ def make_keypoint(class_name: str, x: float, y: float, subs: Optional[List[SubAn
     Annotation
         A point ``Annotation``.
     """
-    return Annotation(AnnotationClass(class_name, "keypoint"), {"x": x, "y": y}, subs or [])
+    return Annotation(AnnotationClass(class_name, "keypoint"), {"x": x, "y": y}, subs or [], slot_names=slot_names)
 
 
-def make_line(class_name: str, path: List[Point], subs: Optional[List[SubAnnotation]] = None) -> Annotation:
+def make_line(
+    class_name: str,
+    path: List[Point],
+    subs: Optional[List[SubAnnotation]] = None,
+    slot_names: Optional[List[str]] = None,
+) -> Annotation:
     """
     Creates and returns a line annotation.
 
@@ -448,10 +480,15 @@ def make_line(class_name: str, path: List[Point], subs: Optional[List[SubAnnotat
     Annotation
         A line ``Annotation``.
     """
-    return Annotation(AnnotationClass(class_name, "line"), {"path": path}, subs or [])
+    return Annotation(AnnotationClass(class_name, "line"), {"path": path}, subs or [], slot_names=slot_names)
 
 
-def make_skeleton(class_name: str, nodes: List[Node], subs: Optional[List[SubAnnotation]] = None) -> Annotation:
+def make_skeleton(
+    class_name: str,
+    nodes: List[Node],
+    subs: Optional[List[SubAnnotation]] = None,
+    slot_names: Optional[List[str]] = None,
+) -> Annotation:
     """
     Creates and returns a skeleton annotation.
 
@@ -479,10 +516,15 @@ def make_skeleton(class_name: str, nodes: List[Node], subs: Optional[List[SubAnn
     Annotation
         A skeleton ``Annotation``.
     """
-    return Annotation(AnnotationClass(class_name, "skeleton"), {"nodes": nodes}, subs or [])
+    return Annotation(AnnotationClass(class_name, "skeleton"), {"nodes": nodes}, subs or [], slot_names=slot_names)
 
 
-def make_ellipse(class_name: str, parameters: EllipseData, subs: Optional[List[SubAnnotation]] = None) -> Annotation:
+def make_ellipse(
+    class_name: str,
+    parameters: EllipseData,
+    subs: Optional[List[SubAnnotation]] = None,
+    slot_names: Optional[List[str]] = None,
+) -> Annotation:
     """
     Creates and returns an Ellipse annotation.
 
@@ -522,10 +564,15 @@ def make_ellipse(class_name: str, parameters: EllipseData, subs: Optional[List[S
     Annotation
         An ellipse ``Annotation``.
     """
-    return Annotation(AnnotationClass(class_name, "ellipse"), parameters, subs or [])
+    return Annotation(AnnotationClass(class_name, "ellipse"), parameters, subs or [], slot_names=slot_names)
 
 
-def make_cuboid(class_name: str, cuboid: CuboidData, subs: Optional[List[SubAnnotation]] = None) -> Annotation:
+def make_cuboid(
+    class_name: str,
+    cuboid: CuboidData,
+    subs: Optional[List[SubAnnotation]] = None,
+    slot_names: Optional[List[str]] = None,
+) -> Annotation:
     """
     Creates and returns a Cuboid annotation.
 
@@ -557,7 +604,7 @@ def make_cuboid(class_name: str, cuboid: CuboidData, subs: Optional[List[SubAnno
     Annotation
         A cuboid ``Annotation``.
     """
-    return Annotation(AnnotationClass(class_name, "cuboid"), cuboid, subs or [])
+    return Annotation(AnnotationClass(class_name, "cuboid"), cuboid, subs or [], slot_names=slot_names)
 
 
 def make_instance_id(value: int) -> SubAnnotation:
@@ -635,7 +682,11 @@ def make_keyframe(annotation: Annotation, idx: int) -> KeyFrame:
 
 
 def make_video_annotation(
-    frames: Dict[int, Any], keyframes: Dict[int, bool], segments: List[Segment], interpolated: bool
+    frames: Dict[int, Any],
+    keyframes: Dict[int, bool],
+    segments: List[Segment],
+    interpolated: bool,
+    slot_names: Optional[List[str]] = None,
 ) -> VideoAnnotation:
     """
     Creates and returns a ``VideoAnnotation``.
@@ -665,7 +716,9 @@ def make_video_annotation(
     if not all(frame.annotation_class.name == first_annotation.annotation_class.name for frame in frames.values()):
         raise ValueError("invalid argument to make_video_annotation")
 
-    return VideoAnnotation(first_annotation.annotation_class, frames, keyframes, segments, interpolated)
+    return VideoAnnotation(
+        first_annotation.annotation_class, frames, keyframes, segments, interpolated, slot_names=slot_names
+    )
 
 
 def _maybe_add_bounding_box_data(data: Dict[str, Any], bounding_box: Optional[Dict]) -> Dict[str, Any]:
